% Auto-generated chapter 79 for bukhari
% Hadiths in this chapter: 75

\hadithdefcmd{bukhari}{6227}{حَدَّثَنَا يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَلَقَ اللَّهُ آدَمَ عَلَى صُورَتِهِ، طُولُهُ سِتُّونَ ذِرَاعًا، فَلَمَّا خَلَقَهُ قَالَ اذْهَبْ فَسَلِّمْ عَلَى أُولَئِكَ النَّفَرِ مِنَ الْمَلاَئِكَةِ جُلُوسٌ، فَاسْتَمِعْ مَا يُحَيُّونَكَ، فَإِنَّهَا تَحِيَّتُكَ وَتَحِيَّةُ ذُرِّيَّتِكَ‏.‏ فَقَالَ السَّلاَمُ عَلَيْكُمْ‏.‏ فَقَالُوا السَّلاَمُ عَلَيْكَ وَرَحْمَةُ اللَّهِ‏.‏ فَزَادُوهُ وَرَحْمَةُ اللَّهِ، فَكُلُّ مَنْ يَدْخُلُ الْجَنَّةَ عَلَى صُورَةِ آدَمَ، فَلَمْ يَزَلِ الْخَلْقُ يَنْقُصُ بَعْدُ حَتَّى الآنَ ‏"‏‏.‏\hadithno{6227}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah created Adam in His picture, sixty cubits (about 30 meters) in height. When He created him, He said (to him), "Go and greet that group of angels sitting there, and listen what they will say in reply to you, for that will be your greeting and the greeting of your offspring." Adam (went and) said, 'As-Salamu alaikum (Peace be upon you).' They replied, 'AsSalamu-'Alaika wa Rahmatullah (Peace and Allah's Mercy be on you) So they increased 'Wa Rahmatullah' The Prophet (ﷺ) added 'So whoever will enter Paradise, will be of the shape and picture of Adam Since then the creation of Adam's (offspring) (i.e. stature of human beings is being diminished continuously) to the present time}}
\hadithdefcmd{bukhari}{6228}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ يَسَارٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَرْدَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْفَضْلَ بْنَ عَبَّاسٍ يَوْمَ النَّحْرِ خَلْفَهُ عَلَى عَجُزِ رَاحِلَتِهِ، وَكَانَ الْفَضْلُ رَجُلاً وَضِيئًا، فَوَقَفَ النَّبِيُّ صلى الله عليه وسلم لِلنَّاسِ يُفْتِيهِمْ، وَأَقْبَلَتِ امْرَأَةٌ مِنْ خَثْعَمَ وَضِيئَةٌ تَسْتَفْتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَطَفِقَ الْفَضْلُ يَنْظُرُ إِلَيْهَا، وَأَعْجَبَهُ حُسْنُهَا، فَالْتَفَتَ النَّبِيُّ صلى الله عليه وسلم يَنْظُرُ إِلَيْهَا، فَأَخْلَفَ بِيَدِهِ فَأَخَذَ بِذَقَنِ الْفَضْلِ، فَعَدَلَ وَجْهَهُ عَنِ النَّظَرِ إِلَيْهَا، فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ فَرِيضَةَ اللَّهِ فِي الْحَجِّ عَلَى عِبَادِهِ أَدْرَكَتْ أَبِي شَيْخًا كَبِيرًا، لاَ يَسْتَطِيعُ أَنْ يَسْتَوِيَ عَلَى الرَّاحِلَةِ، فَهَلْ يَقْضِي عَنْهُ أَنْ أَحُجَّ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏\hadithno{6228}\hadithtrans{Narrated `Abdullah bin `Abbas:Al-Fadl bin `Abbas rode behind the Prophet (ﷺ) as his companion rider on the back portion of his she camel on the Day of Nahr (slaughtering of sacrifice, 10th Dhul-Hijja) and Al-Fadl was a handsome man. The Prophet (ﷺ) stopped to give the people verdicts. In the meantime, a beautiful woman From the tribe of Khath'am came, asking the verdict of Allah's Messenger (ﷺ). Al-Fadl started looking at her as her beauty attracted him. The Prophet (ﷺ) looked behind while Al-Fadl was looking at her; so the Prophet (ﷺ) held out his hand backwards and caught the chin of Al-Fadl and turned his face (to the owner sides in order that he should not gaze at her. She said, "O Allah's Messenger (ﷺ)! The obligation of Performing Hajj enjoined by Allah on His worshipers, has become due (compulsory) on my father who is an old man and who cannot sit firmly on the riding animal. Will it be sufficient that I perform Hajj on his behalf?" He said, "Yes}}
\hadithdefcmd{bukhari}{6229}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا أَبُو عَامِرٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالْجُلُوسَ بِالطُّرُقَاتِ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ مَا لَنَا مِنْ مَجَالِسِنَا بُدٌّ نَتَحَدَّثُ فِيهَا‏.‏ فَقَالَ ‏"‏ إِذَا أَبَيْتُمْ إِلاَّ الْمَجْلِسَ فَأَعْطُوا الطَّرِيقَ حَقَّهُ ‏"‏‏.‏ قَالُوا وَمَا حَقُّ الطَّرِيقِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ غَضُّ الْبَصَرِ، وَكَفُّ الأَذَى، وَرَدُّ السَّلاَمِ، وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏‏.‏\hadithno{6229}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, 'Beware! Avoid sitting on the roads." They (the people) said, "O Allah's Apostle! We can't help sitting (on the roads) as these are (our places) here we have talks." The Prophet (ﷺ) said, 'If you refuse but to sit, then pay the road its right ' They said, "What is the right of the road, O Allah's Apostle?" He said, 'Lowering your gaze, refraining from harming others, returning greeting, and enjoining what is good, and forbidding what is evil}}
\hadithdefcmd{bukhari}{6230}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي شَقِيقٌ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا إِذَا صَلَّيْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم قُلْنَا السَّلاَمُ عَلَى اللَّهِ قَبْلَ عِبَادِهِ، السَّلاَمُ عَلَى جِبْرِيلَ، السَّلاَمُ عَلَى مِيكَائِيلَ، السَّلاَمُ عَلَى فُلاَنٍ، فَلَمَّا انْصَرَفَ النَّبِيُّ صلى الله عليه وسلم أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ هُوَ السَّلاَمُ، فَإِذَا جَلَسَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ، وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ‏.‏ فَإِنَّهُ إِذَا قَالَ ذَلِكَ أَصَابَ كُلَّ عَبْدٍ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ‏.‏ ثُمَّ يَتَخَيَّرْ بَعْدُ مِنَ الْكَلاَمِ مَا شَاءَ ‏"‏‏.‏\hadithno{6230}\hadithtrans{Narrated `Abdullah:When we prayed with the Prophet (ﷺ) we used to say: As-Salam be on Allah from His worshipers, As- Salam be on Gabriel, As-Salam be on Michael, As-Salam be on so-and-so. When the Prophet (ﷺ) finished his prayer, he faced us and said, "Allah Himself is As-Salam (Peace), so when one sits in the prayer, one should say, 'at-Tahiyatu-li l-lahi Was-Salawatu, Wat-Taiyibatu, As-Salamu 'Alaika aiyuhan- Nabiyyu wa Rah-matul-iahi wa Barakatuhu, As-Salamu 'Alaina wa 'ala 'Ibadillahi assalihin, for if he says so, then it will be for all the pious slave of Allah in the Heavens and the Earth. (Then he should say), 'Ash-hadu an la ilaha illalllahu wa ash-hadu anna Muhammadan `Abduhu wa rasulu-hu,' and then he can choose whatever speech (i.e. invocation) he wishes " (See Hadith No. 797, Vol)}}
\hadithdefcmd{bukhari}{6231}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُسَلِّمُ الصَّغِيرُ عَلَى الْكَبِيرِ، وَالْمَارُّ عَلَى الْقَاعِدِ، وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏‏.‏\hadithno{6231}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The young should greet the old, the passer by should greet the sitting one, and the small group of persons should greet the large group of persons}}
\hadithdefcmd{bukhari}{6232}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي زِيَادٌ، أَنَّهُ سَمِعَ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي، وَالْمَاشِي عَلَى الْقَاعِدِ، وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏‏.‏\hadithno{6232}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The riding one should greet the walking one, and the walking one should greet the sitting one, and the small number of persons should greet the large number of persons}}
\hadithdefcmd{bukhari}{6233}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي زِيَادٌ، أَنَّ ثَابِتًا، أَخْبَرَهُ ـ وَهْوَ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ ـ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي وَالْمَاشِي عَلَى الْقَاعِدِ، وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏‏.‏\hadithno{6233}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "The riding person should greet the walking one, and the walking one should greet the sitting one, and the small number of persons should greet the large number of persons}}
\hadithdefcmd{bukhari}{6234}{وَقَالَ إِبْرَاهِيمُ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُسَلِّمُ الصَّغِيرُ عَلَى الْكَبِيرِ، وَالْمَارُّ عَلَى الْقَاعِدِ، وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏‏.‏\hadithno{6234}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "The younger person should greet the older one, and the walking person should greet the sitting one, and the small number of persons should greet the large number of persons}}
\hadithdefcmd{bukhari}{6235}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ بِعِيَادَةِ الْمَرِيضِ، وَاتِّبَاعِ الْجَنَائِزِ، وَتَشْمِيتِ الْعَاطِسِ، وَنَصْرِ الضَّعِيفِ، وَعَوْنِ الْمَظْلُومِ، وَإِفْشَاءِ السَّلاَمِ، وَإِبْرَارِ الْمُقْسِمِ، وَنَهَى عَنِ الشُّرْبِ فِي الْفِضَّةِ، وَنَهَانَا عَنْ تَخَتُّمِ الذَّهَبِ، وَعَنْ رُكُوبِ الْمَيَاثِرِ، وَعَنْ لُبْسِ الْحَرِيرِ، وَالدِّيبَاجِ، وَالْقَسِّيِّ، وَالإِسْتَبْرَقِ‏.‏\hadithno{6235}\hadithtrans{Narrated Al-Bara' bin 'Azib: Allah's Messenger (ﷺ) ordered us to do seven (things): to visit the sick, to follow the funeral processions, to say Tashmit to a sneezer, to help the weak, to help the oppressed ones, to propagate As-Salam (greeting), and to help others to fulfill their oaths (if it is not sinful). He forbade us to drink from silver utensils, to wear gold rings, to ride on silken saddles, to wear silk clothes, Dibaj (thick silk cloth), Qassiy and Istabraq (two kinds of silk). (See Hadith No. 539, Vol)}}
\hadithdefcmd{bukhari}{6236}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَزِيدُ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم أَىُّ الإِسْلاَمِ خَيْرٌ قَالَ ‏ "‏ تُطْعِمُ الطَّعَامَ، وَتَقْرَأُ السَّلاَمَ عَلَى مَنْ عَرَفْتَ، وَعَلَى مَنْ لَمْ تَعْرِفْ ‏"‏‏.‏\hadithno{6236}\hadithtrans{Narrated 'Abdullah bin 'Amr: A man asked the Prophet, "What Islamic traits are the best?" The Prophet said, "Feed the people, and greet those whom you know and those whom you do not know}}
\hadithdefcmd{bukhari}{6237}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ، يَلْتَقِيَانِ فَيَصُدُّ هَذَا، وَيَصُدُّ هَذَا، وَخَيْرُهُمَا الَّذِي يَبْدَأُ بِالسَّلاَمِ ‏"‏‏.‏ وَذَكَرَ سُفْيَانُ أَنَّهُ سَمِعَهُ مِنْهُ ثَلاَثَ مَرَّاتٍ‏.‏\hadithno{6237}\hadithtrans{Narrated Abu Aiyub:The Prophet (ﷺ) said, "It is not lawful for a Muslim to desert (not to speak to) his brother Muslim for more than three days while meeting, one turns his face to one side and the other turns his face to the other side. Lo! The better of the two is the one who starts greeting the other}}
\hadithdefcmd{bukhari}{6238}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّهُ كَانَ ابْنَ عَشْرِ سِنِينَ مَقْدَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، فَخَدَمْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَشْرًا حَيَاتَهُ، وَكُنْتُ أَعْلَمَ النَّاسِ بِشَأْنِ الْحِجَابِ حِينَ أُنْزِلَ، وَقَدْ كَانَ أُبَىُّ بْنُ كَعْبٍ يَسْأَلُنِي عَنْهُ، وَكَانَ أَوَّلَ مَا نَزَلَ فِي مُبْتَنَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِزَيْنَبَ ابْنَةِ جَحْشٍ، أَصْبَحَ النَّبِيُّ صلى الله عليه وسلم بِهَا عَرُوسًا فَدَعَا الْقَوْمَ، فَأَصَابُوا مِنَ الطَّعَامِ ثُمَّ خَرَجُوا، وَبَقِيَ مِنْهُمْ رَهْطٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَطَالُوا الْمُكْثَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَرَجَ وَخَرَجْتُ مَعَهُ كَىْ يَخْرُجُوا، فَمَشَى رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَشَيْتُ مَعَهُ حَتَّى جَاءَ عَتَبَةَ حُجْرَةِ عَائِشَةَ، ثُمَّ ظَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُمْ خَرَجُوا فَرَجَعَ وَرَجَعْتُ مَعَهُ، حَتَّى دَخَلَ عَلَى زَيْنَبَ فَإِذَا هُمْ جُلُوسٌ لَمْ يَتَفَرَّقُوا، فَرَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَعْتُ مَعَهُ، حَتَّى بَلَغَ عَتَبَةَ حُجْرَةِ عَائِشَةَ، فَظَنَّ أَنْ قَدْ خَرَجُوا، فَرَجَعَ وَرَجَعْتُ مَعَهُ، فَإِذَا هُمْ قَدْ خَرَجُوا، فَأُنْزِلَ آيَةُ الْحِجَابِ، فَضَرَبَ بَيْنِي وَبَيْنَهُ سِتْرًا‏.‏\hadithno{6238}\hadithtrans{Narrated Anas bin Malik:that he was a boy of ten at the time when the Prophet (ﷺ) emigrated to Medina. He added: I served Allah's Apostle for ten years (the last part of his life time) and I know more than the people about the occasion whereupon the order of Al-Hijab was revealed (to the Prophet). Ubai b n Ka`b used to ask me about it. It was revealed (for the first time) during the marriage of Allah's Messenger (ﷺ) with Zainab bint Jahsh. In the morning, the Prophet (ﷺ) was a bride-groom of her and he Invited the people, who took their meals and went away, but a group of them remained with Allah's Messenger (ﷺ) and they prolonged their stay. Allah's Messenger (ﷺ) got up and went out, and I too, went out along with him till he came to the lintel of `Aisha's dwelling place. Allah's Messenger (ﷺ) thought that those people had left by then, so he returned, and I too, returned with him till he entered upon Zainab and found that they were still sitting there and had not yet gone. The Prophet (ﷺ) went out again, and so did I with him till he reached the lintel of `Aisha's dwelling place, and then he thought that those people must have left by then, so he returned, and so did I with him, and found those people had gone. At that time the Divine Verse of Al-Hijab was revealed, and the Prophet (ﷺ) set a screen between me and him (his family)}}
\hadithdefcmd{bukhari}{6239}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ أَبِي حَدَّثَنَا أَبُو مِجْلَزٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم زَيْنَبَ دَخَلَ الْقَوْمُ فَطَعِمُوا، ثُمَّ جَلَسُوا يَتَحَدَّثُونَ فَأَخَذَ كَأَنَّهُ يَتَهَيَّأُ لِلْقِيَامِ فَلَمْ يَقُومُوا، فَلَمَّا رَأَى ذَلِكَ قَامَ، فَلَمَّا قَامَ قَامَ مَنْ قَامَ مِنَ الْقَوْمِ وَقَعَدَ بَقِيَّةُ الْقَوْمِ، وَإِنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَ لِيَدْخُلَ، فَإِذَا الْقَوْمُ جُلُوسٌ، ثُمَّ إِنَّهُمْ قَامُوا فَانْطَلَقُوا فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم فَجَاءَ حَتَّى دَخَلَ، فَذَهَبْتُ أَدْخُلُ فَأَلْقَى الْحِجَابَ بَيْنِي وَبَيْنَهُ، وَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ‏\}‏ الآيَةَ‏.‏ قَالَ أَبُو عَبْد اللَّهِ فِيهِ مِنْ الْفِقْهِ أَنَّهُ لَمْ يَسْتَأْذِنْهُمْ حِينَ قَامَ وَخَرَجَ وَفِيهِ أَنَّهُ تَهَيَّأَ لِلْقِيَامِ وَهُوَ يُرِيدُ أَنْ يَقُومُوا\hadithno{6239}\hadithtrans{Narrated Anas:When the Prophet (ﷺ) married Zainab, the people came and were offered a meal, and then they sat down (after finishing their meals) and started chatting. The Prophet (ﷺ) showed as if he wanted to get up, but they did not get up. When he noticed that, he got up, and some of the people also got up and went away, while some others kept on sitting. When the Prophet (ﷺ) returned to enter, he found the people still sitting, but then they got up and left. So I told the Prophet (ﷺ) of their departure and he came and went in. I intended to go in but the Prophet (ﷺ) put a screen between me and him, for Allah revealed:-- 'O you who believe! Enter not the Prophet's houses}}
\hadithdefcmd{bukhari}{6240}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ عُمَرُ بْنُ الْخَطَّابِ يَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم احْجُبْ نِسَاءَكَ‏.‏ قَالَتْ فَلَمْ يَفْعَلْ، وَكَانَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم يَخْرُجْنَ لَيْلاً إِلَى لَيْلٍ قِبَلَ الْمَنَاصِعِ، خَرَجَتْ سَوْدَةُ بِنْتُ زَمْعَةَ، وَكَانَتِ امْرَأَةً طَوِيلَةً فَرَآهَا عُمَرُ بْنُ الْخَطَّابِ وَهْوَ فِي الْمَجْلِسِ فَقَالَ عَرَفْتُكِ يَا سَوْدَةُ‏.‏ حِرْصًا عَلَى أَنْ يُنْزَلَ الْحِجَابُ‏.‏ قَالَتْ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ آيَةَ الْحِجَابِ‏.‏\hadithno{6240}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) `Umar bin Al-Khattab used to say to Allah's Messenger (ﷺ) "Let your wives be veiled" But he did not do so. The wives of the Prophet (ﷺ) used to go out to answer the call of nature at night only at Al-Manasi.' Once Sauda, the daughter of Zam`a went out and she was a tall woman. `Umar bin Al-Khattab saw her while he was in a gathering, and said, "I have recognized you, O Sauda!" He (`Umar) said so as he was anxious for some Divine orders regarding the veil (the veiling of women.) So Allah revealed the Verse of veiling. (Al-Hijab; a complete body cover excluding the eyes). (See Hadith No. 148, Vol)}}
\hadithdefcmd{bukhari}{6241}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ حَفِظْتُهُ كَمَا أَنَّكَ هَا هُنَا عَنْ سَهْلِ بْنِ سَعْدٍ قَالَ اطَّلَعَ رَجُلٌ مِنْ جُحْرٍ فِي حُجَرِ النَّبِيِّ صلى الله عليه وسلم وَمَعَ النَّبِيِّ صلى الله عليه وسلم مِدْرًى يَحُكُّ بِهِ رَأْسَهُ فَقَالَ ‏ "‏ لَوْ أَعْلَمُ أَنَّكَ تَنْظُرُ لَطَعَنْتُ بِهِ فِي عَيْنِكَ، إِنَّمَا جُعِلَ الاِسْتِئْذَانُ مِنْ أَجْلِ الْبَصَرِ ‏"‏‏.‏\hadithno{6241}\hadithtrans{Narrated Sahl bin Sa`d:A man peeped through a round hole into the dwelling place of the Prophet, while the Prophet (ﷺ) had a Midray (an iron comb) with which he was scratching his head. the Prophet (ﷺ) said, " Had known you were looking (through the hole), I would have pierced your eye with it (i.e., the comb)." Verily! The order of taking permission to enter has been enjoined because of that sight, (that one should not look unlawfully at the state of others). (See Hadith No. 807, Vol)}}
\hadithdefcmd{bukhari}{6242}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، اطَّلَعَ مِنْ بَعْضِ حُجَرِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم بِمِشْقَصٍ ـ أَوْ بِمَشَاقِصَ ـ فَكَأَنِّي أَنْظُرُ إِلَيْهِ يَخْتِلُ الرَّجُلَ لِيَطْعُنَهُ‏.‏\hadithno{6242}\hadithtrans{Narrated Anas bin Malik:A man peeped into a room of the Prophet. The Prophet (ﷺ) stood up, holding an arrow head. It is as if I am just looking at him, trying to stab the man}}
\hadithdefcmd{bukhari}{6243}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمْ أَرَ شَيْئًا أَشْبَهَ بِاللَّمَمِ مِنْ قَوْلِ أَبِي هُرَيْرَةَ‏.‏ حَدَّثَنِي مَحْمُودٌ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ عَنِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ عَنِ ابْنِ عَبَّاسٍ قَالَ مَا رَأَيْتُ شَيْئًا أَشْبَهَ بِاللَّمَمِ مِمَّا قَالَ أَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ كَتَبَ عَلَى ابْنِ آدَمَ حَظَّهُ مِنَ الزِّنَا، أَدْرَكَ ذَلِكَ لاَ مَحَالَةَ، فَزِنَا الْعَيْنِ النَّظَرُ، وَزِنَا اللِّسَانِ الْمَنْطِقُ، وَالنَّفْسُ تَمَنَّى وَتَشْتَهِي، وَالْفَرْجُ يُصَدِّقُ ذَلِكَ كُلَّهُ وَيُكَذِّبُهُ ‏"‏‏.‏\hadithno{6243}\hadithtrans{Narrated Ibn `Abbas:I have not seen a thing resembling 'lamam' (minor sins) than what Abu Huraira 'narrated from the Prophet who said "Allah has written for Adam's son his share of adultery which he commits inevitably. The adultery of the eyes is the sight (to gaze at a forbidden thing), the adultery of the tongue is the talk, and the inner self wishes and desires and the private parts testify all this or deny it}}
\hadithdefcmd{bukhari}{6244}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، حَدَّثَنَا ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسٍ ـ رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ سَلَّمَ ثَلاَثًا، وَإِذَا تَكَلَّمَ بِكَلِمَةٍ أَعَادَهَا ثَلاَثًا‏.‏\hadithno{6244}\hadithtrans{Narrated Anas:Whenever Allah's Messenger (ﷺ) greeted somebody, he used to greet him three times, and if he spoke a sentence, he used to repeat it thrice}}
\hadithdefcmd{bukhari}{6245}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا يَزِيدُ بْنُ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنْتُ فِي مَجْلِسٍ مِنْ مَجَالِسِ الأَنْصَارِ إِذْ جَاءَ أَبُو مُوسَى كَأَنَّهُ مَذْعُورٌ فَقَالَ اسْتَأْذَنْتُ عَلَى عُمَرَ ثَلاَثًا، فَلَمْ يُؤْذَنْ لِي فَرَجَعْتُ فَقَالَ مَا مَنَعَكَ قُلْتُ اسْتَأْذَنْتُ ثَلاَثًا، فَلَمْ يُؤْذَنْ لِي فَرَجَعْتُ، وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدُكُمْ ثَلاَثًا فَلَمْ يُؤْذَنْ لَهُ، فَلْيَرْجِعْ ‏"‏‏.‏ فَقَالَ وَاللَّهِ لَتُقِيمَنَّ عَلَيْهِ بِبَيِّنَةٍ‏.‏ أَمِنْكُمْ أَحَدٌ سَمِعَهُ مِنَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ أُبَىُّ بْنُ كَعْبٍ وَاللَّهِ لاَ يَقُومُ مَعَكَ إِلاَّ أَصْغَرُ الْقَوْمِ، فَكُنْتُ أَصْغَرَ الْقَوْمِ، فَقُمْتُ مَعَهُ فَأَخْبَرْتُ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ذَلِكَ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ أَخْبَرَنِي ابْنُ عُيَيْنَةَ حَدَّثَنِي يَزِيدُ عَنْ بُسْرٍ سَمِعْتُ أَبَا سَعِيدٍ بِهَذَا‏.‏\hadithno{6245}\hadithtrans{Narrated Abu Sa`id Al-Khudri:While I was present in one of the gatherings of the Ansar, Abu Musa came as if he was scared, and said, "I asked permission to enter upon `Umar three times, but I was not given the permission, so I returned." (When `Umar came to know about it) he said to Abu Musa, "Why did you not enter?'. Abu Musa replied, "I asked permission three times, and I was not given it, so I returned, for Allah's Messenger (ﷺ) said, "If anyone of you asks the permission to enter thrice, and the permission is not given, then he should return.' " `Umar said, "By Allah! We will ask Abu Musa to bring witnesses for it." (Abu Musa went to a gathering of the Ansar and said). "Did anyone of you hear this from the Prophet (ﷺ) ?" Ubai bin Ka`b said, "By Allah, none will go with you but the youngest of the people (as a witness)." (Abu Sa`id) was the youngest of them, so I went with Abu Musa and informed `Umar that the Prophet (ﷺ) had said so. (See Hadith No. 277, Vol)}}
\hadithdefcmd{bukhari}{6246}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ،‏.‏ وَحَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُمَرُ بْنُ ذَرٍّ، أَخْبَرَنَا مُجَاهِدٌ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ دَخَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدَ لَبَنًا فِي قَدَحٍ فَقَالَ ‏ "‏ أَبَا هِرٍّ الْحَقْ أَهْلَ الصُّفَّةِ فَادْعُهُمْ إِلَىَّ ‏"‏‏.‏ قَالَ فَأَتَيْتُهُمْ فَدَعَوْتُهُمْ، فَأَقْبَلُوا فَاسْتَأْذَنُوا فَأُذِنَ لَهُمْ، فَدَخَلُوا‏.‏\hadithno{6246}\hadithtrans{Narrated Abu Huraira:I entered (the house) along with Allah's Messenger (ﷺ) . There he found milk in a basin. He said, "O Abu Hirr! Go and call the people of Suffa to me." I went to them and invited them. They came and asked permission to enter, and when it was given, they entered. (See Hadith No. 459 for details)}}
\hadithdefcmd{bukhari}{6247}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ سَيَّارٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه أَنَّهُ مَرَّ عَلَى صِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ وَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَفْعَلُهُ‏.‏\hadithno{6247}\hadithtrans{Narrated Anas bin Malik:that he passed by a group of boys and greeted them and said, "The Prophet (ﷺ) used to do so}}
\hadithdefcmd{bukhari}{6248}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ كُنَّا نَفْرَحُ يَوْمَ الْجُمُعَةِ‏.‏ قُلْتُ وَلِمَ قَالَ كَانَتْ لَنَا عَجُوزٌ تُرْسِلُ إِلَى بُضَاعَةَ ـ قَالَ ابْنُ مَسْلَمَةَ نَخْلٍ بِالْمَدِينَةِ ـ فَتَأْخُذُ مِنْ أُصُولِ السِّلْقِ فَتَطْرَحُهُ فِي قِدْرٍ، وَتُكَرْكِرُ حَبَّاتٍ مِنْ شَعِيرٍ، فَإِذَا صَلَّيْنَا الْجُمُعَةَ انْصَرَفْنَا وَنُسَلِّمُ عَلَيْهَا فَتُقَدِّمُهُ إِلَيْنَا، فَنَفْرَحُ مِنْ أَجْلِهِ، وَمَا كُنَّا نَقِيلُ وَلاَ نَتَغَدَّى إِلاَّ بَعْدَ الْجُمُعَةِ‏.‏\hadithno{6248}\hadithtrans{Narrated Abu Hazim:Sahl said, "We used to feel happy on Fridays." I asked Sahl, "Why?" He said, "There was an old woman of our acquaintance who used to send somebody to Buda'a (Ibn Maslama said, "Buda'a was a garden of date-palms at Medina). She used to pull out the silq (a kind of vegetable) from its roots and put it in a cooking pot, adding some powdered barley over it (and cook it). After finishing the Jumua (Friday) prayer we used to (pass by her and) greet her, whereupon she would present us with that meal, so we used to feel happy because of that. We used to have neither a midday nap, nor meals, except after the Friday prayer." (See Hadith No. 60, Vol)}}
\hadithdefcmd{bukhari}{6249}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَائِشَةُ هَذَا جِبْرِيلُ يَقْرَأُ عَلَيْكِ السَّلاَمَ ‏"‏‏.‏ قَالَتْ قُلْتُ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ، تَرَى مَا لاَ نَرَى‏.‏ تُرِيدُ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ تَابَعَهُ شُعَيْبٌ‏.‏ وَقَالَ يُونُسُ وَالنُّعْمَانُ عَنِ الزُّهْرِيِّ وَبَرَكَاتُهُ‏.‏\hadithno{6249}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "O `Aisha! This is Gabriel sending his greetings to you." I said, "Peace, and Allah's Mercy be on him (Gabriel). You see what we do not see." (She was addressing Allah's Apostle)}}
\hadithdefcmd{bukhari}{6250}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرًا ـ رضى الله عنه ـ يَقُولُ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي دَيْنٍ كَانَ عَلَى أَبِي فَدَقَقْتُ الْبَابَ فَقَالَ ‏"‏ مَنْ ذَا ‏"‏‏.‏ فَقُلْتُ أَنَا‏.‏ فَقَالَ ‏"‏ أَنَا أَنَا ‏"‏‏.‏ كَأَنَّهُ كَرِهَهَا‏.‏\hadithno{6250}\hadithtrans{Narrated Jabir:I came to the Prophet (ﷺ) in order to consult him regarding my father's debt. When I knocked on the door, he asked, "Who is that?" I replied, "I" He said, "I, I?" He repeated it as if he disliked it}}
\hadithdefcmd{bukhari}{6251}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فِي نَاحِيَةِ الْمَسْجِدِ فَصَلَّى، ثُمَّ جَاءَ فَسَلَّمَ عَلَيْهِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ السَّلاَمُ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ فَرَجَعَ فَصَلَّى، ثُمَّ جَاءَ فَسَلَّمَ‏.‏ فَقَالَ ‏"‏ وَعَلَيْكَ السَّلاَمُ فَارْجِعْ فَصَلِّ، فَإِنَّكَ لَمْ تُصَلِّ ‏"‏‏.‏ فَقَالَ فِي الثَّانِيَةِ أَوْ فِي الَّتِي بَعْدَهَا عَلِّمْنِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَأَسْبِغِ الْوُضُوءَ، ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ فَكَبِّرْ، ثُمَّ اقْرَأْ بِمَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ، ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا، ثُمَّ ارْفَعْ حَتَّى تَسْتَوِيَ قَائِمًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا، ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا، ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا، ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏‏.‏ وَقَالَ أَبُو أُسَامَةَ فِي الأَخِيرِ ‏"‏ حَتَّى تَسْتَوِيَ قَائِمًا ‏"‏‏.‏\hadithno{6251}\hadithtrans{Narrated Abu Huraira:A man entered the mosque while Allah's Messenger (ﷺ) was sitting in one side of the mosque. The man prayed, came, and greeted the Prophet. Allah's Messenger (ﷺ) said to him, "Wa 'Alaikas Salam (returned his greeting). Go back and pray as you have not prayed (properly)." The man returned, repeated his prayer, came back and greeted the Prophet. The Prophet (ﷺ) said, "Wa alaika-s-Salam (returned his greeting). Go back and pray again as you have not prayed (properly)." The man said at the second or third time, "O Allah's Messenger (ﷺ)! Kindly teach me how to pray". The Prophet (ﷺ) said, "When you stand for prayer, perform ablution properly and then face the Qibla and say Takbir (Allahu-Akbar), and then recite what you know from the Qur'an, and then bow with calmness till you feel at ease then rise from bowing, till you stand straight, and then prostrate calmly (and remain in prostration) till you feel at ease, and then raise (your head) and sit with calmness till you feel at ease and then prostrate with calmness (and remain in prostration) till you feel at ease, and then raise (your head) and sit with calmness till you feel at ease in the sitting position, and do likewise in whole of your prayer." And Abu Usama added, "Till you stand straight." (See Hadith No. 759, Vol)}}
\hadithdefcmd{bukhari}{6252}{حَدَّثَنَا ابْنُ بَشَّارٍ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي سَعِيدٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا ‏"‏‏.‏\hadithno{6252}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said (in the above narration No. 268), "And then raise your head till you feel at ease while sitting}}
\hadithdefcmd{bukhari}{6253}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، قَالَ سَمِعْتُ عَامِرًا، يَقُولُ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ جِبْرِيلَ يُقْرِئُكِ السَّلاَمَ ‏"‏‏.‏ قَالَتْ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ‏.‏\hadithno{6253}\hadithtrans{Narrated `Aisha:That the Prophet (ﷺ) said to her, "Gabriel sends Salam (greetings) to you." She replied, "Wa 'alaihi-s- Salam Wa Rahmatu-l-lah." (Peace and Allah's Mercy be on him)}}
\hadithdefcmd{bukhari}{6254}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَكِبَ حِمَارًا عَلَيْهِ إِكَافٌ، تَحْتَهُ قَطِيفَةٌ فَدَكِيَّةٌ، وَأَرْدَفَ وَرَاءَهُ أُسَامَةَ بْنَ زَيْدٍ وَهْوَ يَعُودُ سَعْدَ بْنَ عُبَادَةَ فِي بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ، وَذَلِكَ قَبْلَ وَقْعَةِ بَدْرٍ حَتَّى مَرَّ فِي مَجْلِسٍ فِيهِ أَخْلاَطٌ مِنَ الْمُسْلِمِينَ وَالْمُشْرِكِينَ عَبَدَةِ الأَوْثَانِ وَالْيَهُودِ، وَفِيهِمْ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ، وَفِي الْمَجْلِسِ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ، فَلَمَّا غَشِيَتِ الْمَجْلِسَ عَجَاجَةُ الدَّابَّةِ خَمَّرَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَنْفَهُ بِرِدَائِهِ ثُمَّ قَالَ لاَ تُغَبِّرُوا عَلَيْنَا‏.‏ فَسَلَّمَ عَلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم ثُمَّ وَقَفَ فَنَزَلَ، فَدَعَاهُمْ إِلَى اللَّهِ وَقَرَأَ عَلَيْهِمُ الْقُرْآنَ فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ أَيُّهَا الْمَرْءُ لاَ أَحْسَنَ مِنْ هَذَا، إِنْ كَانَ مَا تَقُولُ حَقًّا، فَلاَ تُؤْذِنَا فِي مَجَالِسِنَا، وَارْجِعْ إِلَى رَحْلِكَ، فَمَنْ جَاءَكَ مِنَّا فَاقْصُصْ عَلَيْهِ‏.‏ قَالَ ابْنُ رَوَاحَةَ اغْشَنَا فِي مَجَالِسِنَا، فَإِنَّا نُحِبُّ ذَلِكَ‏.‏ فَاسْتَبَّ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْيَهُودُ حَتَّى هَمُّوا أَنْ يَتَوَاثَبُوا، فَلَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُخَفِّضُهُمْ، ثُمَّ رَكِبَ دَابَّتَهُ حَتَّى دَخَلَ عَلَى سَعْدِ بْنِ عُبَادَةَ فَقَالَ ‏ "‏ أَىْ سَعْدُ أَلَمْ تَسْمَعْ مَا قَالَ أَبُو حُبَابٍ ‏"‏‏.‏ يُرِيدُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ قَالَ كَذَا وَكَذَا قَالَ اعْفُ عَنْهُ يَا رَسُولَ اللَّهِ وَاصْفَحْ فَوَاللَّهِ لَقَدْ أَعْطَاكَ اللَّهُ الَّذِي أَعْطَاكَ، وَلَقَدِ اصْطَلَحَ أَهْلُ هَذِهِ الْبَحْرَةِ عَلَى أَنْ يُتَوِّجُوهُ فَيُعَصِّبُونَهُ بِالْعِصَابَةِ، فَلَمَّا رَدَّ اللَّهُ ذَلِكَ بِالْحَقِّ الَّذِي أَعْطَاكَ شَرِقَ بِذَلِكَ، فَذَلِكَ فَعَلَ بِهِ مَا رَأَيْتَ، فَعَفَا عَنْهُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{6254}\hadithtrans{Narrated `Urwa-bin Az-Zubair:Usama bin Zaid said, "The Prophet (ﷺ) rode over a donkey with a saddle underneath which there was a thick soft Fadakiya velvet sheet. Usama bin Zaid was his companion rider, and he was going to pay a visit to Sa`d bin Ubada (who was sick) at the dwelling place of Bani Al-Harith bin Al-Khazraj, and this incident happened before the battle of Badr. The Prophet (ﷺ) passed by a gathering in which there were Muslims and pagan idolators and Jews, and among them there was `Abdullah bin Ubai bin Salul, and there was `Abdullah bin Rawaha too. When a cloud of dust raised by the animal covered that gathering, `Abdullah bin Ubai covered his nose with his Rida (sheet) and said (to the Prophet), "Don't cover us with dust." The Prophet (ﷺ) greeted them and then stopped, dismounted and invited them to Allah (i.e., to embrace Islam) and also recited to them the Holy Qur'an. `Abdullah bin Ubai' bin Salul said, "O man! There is nothing better than what you say, if what you say is the truth. So do not trouble us in our gatherings. Go back to your mount (or house,) and if anyone of us comes to you, tell (your tales) to him." On that `Abdullah bin Rawaha said, "(O Allah's Messenger (ﷺ)!) Come to us and bring it(what you want to say) in our gatherings, for we love that." So the Muslims, the pagans and the Jews started quarreling till they were about to fight and clash with one another. The Prophet (ﷺ) kept on quietening them (till they all became quiet). He then rode his animal, and proceeded till he entered upon Sa`d bin 'Ubada, he said, "O Sa`d, didn't you hear what Abu Habbab said? (He meant `Abdullah bin Ubai). He said so-and-so." Sa`d bin 'Ubada said, "O Allah's Messenger (ﷺ)! Excuse and forgive him, for by Allah, Allah has given you what He has given you. The people of this town decided to crown him (as their chief) and make him their king. But when Allah prevented that with the Truth which He had given you, it choked him, and that was what made him behave in the way you saw him behaving." So the Prophet excused him}}
\hadithdefcmd{bukhari}{6255}{حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حِينَ تَخَلَّفَ عَنْ تَبُوكَ، وَنَهَى، رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كَلاَمِنَا، وَآتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَأُسَلِّمُ عَلَيْهِ، فَأَقُولُ فِي نَفْسِي هَلْ حَرَّكَ شَفَتَيْهِ بِرَدِّ السَّلاَمِ أَمْ لاَ حَتَّى كَمَلَتْ خَمْسُونَ لَيْلَةً، وَآذَنَ النَّبِيُّ صلى الله عليه وسلم بِتَوْبَةِ اللَّهِ عَلَيْنَا حِينَ صَلَّى الْفَجْرَ‏.‏\hadithno{6255}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik narrating (when he did not join the battle of Tabuk): Allah's Messenger (ﷺ) forbade all the Muslims to speak to us. I would come to Allah's Messenger (ﷺ) and greet him, and I would wonder whether the Prophet (ﷺ) did move his lips to return to my greetings or not till fifty nights passed away. The Prophet (ﷺ) then announced (to the people) Allah's forgiveness for us (acceptance of our repentance) at the time when he had offered the Fajr (morning) prayer}}
\hadithdefcmd{bukhari}{6256}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ رَهْطٌ مِنَ الْيَهُودِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ‏.‏ فَفَهِمْتُهَا فَقُلْتُ عَلَيْكُمُ السَّامُ وَاللَّعْنَةُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْلاً يَا عَائِشَةُ، فَإِنَّ اللَّهَ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَوَلَمْ تَسْمَعْ مَا قَالُوا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَقَدْ قُلْتُ وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{6256}\hadithtrans{Narrated `Aisha:A group of Jews came to Allah's Messenger (ﷺ) and said, "As-samu 'Alaika " (Death be on you), and I understood it and said to them, "Alaikum AsSamu wa-l-la'na (Death and curse be on you)." Allah's Apostle said, "Be calm! O `Aisha, for Allah loves that one should be kind and lenient in all matters." I said. "O Allah's Messenger (ﷺ)! Haven't you heard what they have said?" Allah's Messenger (ﷺ) said, "I have (already) said (to them), 'Alaikum (upon you)}}
\hadithdefcmd{bukhari}{6257}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَلَّمَ عَلَيْكُمُ الْيَهُودُ فَإِنَّمَا يَقُولُ أَحَدُهُمُ السَّامُ عَلَيْكَ‏.‏ فَقُلْ وَعَلَيْكَ ‏"‏‏.‏\hadithno{6257}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "When the Jews greet you, they usually say, 'As-Samu 'alaikum (Death be on you),' so you should say (in reply to them), 'Wa'alaikum (And on you)}}
\hadithdefcmd{bukhari}{6258}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا سَلَّمَ عَلَيْكُمْ أَهْلُ الْكِتَابِ فَقُولُوا وَعَلَيْكُمْ ‏"‏‏.‏\hadithno{6258}\hadithtrans{Narrated Anas bin Malik:the Prophet (ﷺ) said, "If the people of the Scripture greet you, then you should say (in reply), 'Wa'alaikum (And on you)}}
\hadithdefcmd{bukhari}{6259}{حَدَّثَنَا يُوسُفُ بْنُ بُهْلُولٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ حَدَّثَنِي حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَالزُّبَيْرَ بْنَ الْعَوَّامِ وَأَبَا مَرْثَدٍ الْغَنَوِيَّ وَكُلُّنَا فَارِسٌ فَقَالَ ‏"‏ انْطَلِقُوا حَتَّى تَأْتُوا رَوْضَةَ خَاخٍ، فَإِنَّ بِهَا امْرَأَةً مِنَ الْمُشْرِكِينَ مَعَهَا صَحِيفَةٌ مِنْ حَاطِبِ بْنِ أَبِي بَلْتَعَةَ إِلَى الْمُشْرِكِينَ ‏"‏‏.‏ قَالَ فَأَدْرَكْنَاهَا تَسِيرُ عَلَى جَمَلٍ لَهَا حَيْثُ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ قُلْنَا أَيْنَ الْكِتَابُ الَّذِي مَعَكِ قَالَتْ مَا مَعِي كِتَابٌ‏.‏ فَأَنَخْنَا بِهَا، فَابْتَغَيْنَا فِي رَحْلِهَا فَمَا وَجَدْنَا شَيْئًا، قَالَ صَاحِبَاىَ مَا نَرَى كِتَابًا‏.‏ قَالَ قُلْتُ لَقَدْ عَلِمْتُ مَا كَذَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِي يُحْلَفُ بِهِ لَتُخْرِجِنَّ الْكِتَابَ أَوْ لأُجَرِّدَنَّكِ‏.‏ قَالَ فَلَمَّا رَأَتِ الْجِدَّ مِنِّي أَهْوَتْ بِيَدِهَا إِلَى حُجْزَتِهَا وَهْىَ مُحْتَجِزَةٌ بِكِسَاءٍ فَأَخْرَجَتِ الْكِتَابَ ـ قَالَ ـ فَانْطَلَقْنَا بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا حَمَلَكَ يَا حَاطِبُ عَلَى مَا صَنَعْتَ ‏"‏‏.‏ قَالَ مَا بِي إِلاَّ أَنْ أَكُونَ مُؤْمِنًا بِاللَّهِ وَرَسُولِهِ، وَمَا غَيَّرْتُ وَلاَ بَدَّلْتُ، أَرَدْتُ أَنْ تَكُونَ لِي عِنْدَ الْقَوْمِ يَدٌ يَدْفَعُ اللَّهُ بِهَا عَنْ أَهْلِي وَمَالِي، وَلَيْسَ مِنْ أَصْحَابِكَ هُنَاكَ إِلاَّ وَلَهُ مَنْ يَدْفَعُ اللَّهُ بِهِ عَنْ أَهْلِهِ وَمَالِهِ‏.‏ قَالَ ‏"‏ صَدَقَ فَلاَ تَقُولُوا لَهُ إِلاَّ خَيْرًا ‏"‏‏.‏ قَالَ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ إِنَّهُ قَدْ خَانَ اللَّهَ وَرَسُولَهُ وَالْمُؤْمِنِينَ، فَدَعْنِي فَأَضْرِبَ عُنُقَهُ‏.‏ قَالَ فَقَالَ ‏"‏ يَا عُمَرُ وَمَا يُدْرِيكَ لَعَلَّ اللَّهَ قَدِ اطَّلَعَ عَلَى أَهْلِ بَدْرٍ فَقَالَ اعْمَلُوا مَا شِئْتُمْ فَقَدْ وَجَبَتْ لَكُمُ الْجَنَّةُ ‏"‏‏.‏ قَالَ فَدَمَعَتْ عَيْنَا عُمَرَ وَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏\hadithno{6259}\hadithtrans{Narrated `Ali:Allah's Messenger (ﷺ) sent me, Az-Zubair bin Al-Awwam and Abu Marthad Al-Ghanawi, and all of us were horsemen, and he said, "Proceed till you reach Rawdat Khakh, where there is a woman from the pagans carrying a letter sent by Hatib bin Abi Balta'a to the pagans (of Mecca)." So we overtook her while she was proceeding on her camel at the same place as Allah's Messenger (ﷺ) told us. We said (to her) "Where is the letter which is with you?" She said, "I have no letter with me." So we made her camel kneel down and searched her mount (baggage etc) but could not find anything. My two companions said, "We do not see any letter." I said, "I know that Allah's Messenger (ﷺ) did not tell a lie. By Allah, if you (the lady) do not bring out the letter, I will strip you of your clothes' When she noticed that I was serious, she put her hand into the knot of her waist sheet, for she was tying a sheet round herself, and brought out the letter. So we proceeded to Allah's Messenger (ﷺ) with the letter. The Prophet (ﷺ) said (to Habib), "What made you o what you have done, O Hatib?" Hatib replied, "I have done nothing except that I believe in Allah and His Apostle, and I have not changed or altered (my religion). But I wanted to do the favor to the people (pagans of Mecca) through which Allah might protect my family and my property, as there is none among your companions but has someone in Mecca through whom Allah protects his property (against harm). The Prophet (ﷺ) said, "Habib has told you the truth, so do not say to him (anything) but good." `Umar bin Al-Khattab said, "Verily he has betrayed Allah, His Apostle, and the believers! Allow me to chop his neck off!" The Prophet (ﷺ) said, "O `Umar! What do you know; perhaps Allah looked upon the Badr warriors and said, 'Do whatever you like, for I have ordained that you will be in Paradise.'" On that `Umar wept and said, "Allah and His Apostle know best}}
\hadithdefcmd{bukhari}{6260}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ بْنَ حَرْبٍ أَخْبَرَهُ أَنَّ هِرَقْلَ أَرْسَلَ إِلَيْهِ فِي نَفَرٍ مِنْ قُرَيْشٍ وَكَانُوا تِجَارًا بِالشَّأْمِ، فَأَتَوْهُ فَذَكَرَ الْحَدِيثَ قَالَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُرِئَ فَإِذَا فِيهِ ‏ "‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ، مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ إِلَى هِرَقْلَ عَظِيمِ الرُّومِ، السَّلاَمُ عَلَى مَنِ اتَّبَعَ الْهُدَى، أَمَّا بَعْدُ ‏"‏‏.‏\hadithno{6260}\hadithtrans{Narrated Abu Sufyan bin Harb:that Heraclius had sent for him to come along with a group of the Quraish who were trading in Sha'm, and they came to him. Then Abu Sufyan mentioned the whole narration and said, "Heraclius asked for the letter of Allah's Messenger (ﷺ) . When the letter was read, its contents were as follows: 'In the name of Allah, the Beneficent, the Merciful. From Muhammad, Allah's slave and His Apostle to Heraclius, the Chief of Byzantines: Peace be upon him who follows the right path (guidance)! Amma ba'du (to proceed )...' (See Hadith No 6, Vol 1 for details)}}
\hadithdefcmd{bukhari}{6261}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ أَخَذَ خَشَبَةً فَنَقَرَهَا، فَأَدْخَلَ فِيهَا أَلْفَ دِينَارٍ وَصَحِيفَةً مِنْهُ إِلَى صَاحِبِهِ‏.‏ وَقَالَ عُمَرُ بْنُ أَبِي سَلَمَةَ عَنْ أَبِيهِ سَمِعَ أَبَا هُرَيْرَةَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَجَرَ خَشَبَةً، فَجَعَلَ الْمَالَ فِي جَوْفِهَا، وَكَتَبَ إِلَيْهِ صَحِيفَةً مِنْ فُلاَنٍ إِلَى فُلاَنٍ ‏"‏‏.‏\hadithno{6261}\hadithtrans{Narrated Abu Hurairah (ra):Allah's Messenger (ﷺ) mentioned a person from Bani Israel who took a piece of wood, made a hole in it, and put therein one thousand Dinar and letter from him to his friend. The Prophet (ﷺ) said, "(That man) cut a piece of wood and put the money inside it and wrote a letter from such and such a person to such and such a person}}
\hadithdefcmd{bukhari}{6262}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ أَهْلَ، قُرَيْظَةَ نَزَلُوا عَلَى حُكْمِ سَعْدٍ فَأَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَيْهِ فَجَاءَ فَقَالَ ‏"‏ قُومُوا إِلَى سَيِّدِكُمْ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ خَيْرِكُمْ ‏"‏‏.‏ فَقَعَدَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ هَؤُلاَءِ نَزَلُوا عَلَى حُكْمِكَ ‏"‏‏.‏ قَالَ فَإِنِّي أَحْكُمُ أَنْ تُقْتَلَ مُقَاتِلَتُهُمْ، وَتُسْبَى ذَرَارِيُّهُمْ‏.‏ فَقَالَ ‏"‏ لَقَدْ حَكَمْتَ بِمَا حَكَمَ بِهِ الْمَلِكُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ أَفْهَمَنِي بَعْضُ أَصْحَابِي عَنْ أَبِي الْوَلِيدِ مِنْ قَوْلِ أَبِي سَعِيدٍ إِلَى حُكْمِكَ‏.‏\hadithno{6262}\hadithtrans{Narrated Abu Sa`id:The people of (the tribe of) Quraiza agreed upon to accept the verdict of Sa`d. The Prophet (ﷺ) sent for him (Sa`d) and he came. The Prophet (ﷺ) said (to those people), "Get up for your chief or the best among you!" Sa`d sat beside the Prophet (ﷺ) and the Prophet (ﷺ) said (to him), "These people have agreed to accept your verdict." Sa`d said, "So I give my judgment that their warriors should be killed and their women and children should be taken as captives." The Prophet (ﷺ) said, "You have judged according to the King's (Allah's) judgment." (See Hadith No. 447, Vol)}}
\hadithdefcmd{bukhari}{6263}{حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ قُلْتُ لأَنَسٍ أَكَانَتِ الْمُصَافَحَةُ فِي أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ نَعَمْ‏.‏\hadithno{6263}\hadithtrans{Narrated Qatada:I asked Anas, "Was it a custom of the companions of the Prophet (ﷺ) to shake hands with one another?" He said, "Yes}}
\hadithdefcmd{bukhari}{6264}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي حَيْوَةُ، قَالَ حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ سَمِعَ جَدَّهُ عَبْدَ اللَّهِ بْنَ هِشَامٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهْوَ آخِذٌ بِيَدِ عُمَرَ بْنِ الْخَطَّابِ‏.‏\hadithno{6264}\hadithtrans{Narrated `Abdullah bin Hisham:We were in the company of the Prophet (ﷺ) and he was holding the hand of `Umar bin Al-Khattab}}
\hadithdefcmd{bukhari}{6265}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَيْفٌ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَخْبَرَةَ أَبُو مَعْمَرٍ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ، يَقُولُ عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَفِّي بَيْنَ كَفَّيْهِ التَّشَهُّدَ، كَمَا يُعَلِّمُنِي السُّورَةَ مِنَ الْقُرْآنِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ‏.‏ وَهْوَ بَيْنَ ظَهْرَانَيْنَا، فَلَمَّا قُبِضَ قُلْنَا السَّلاَمُ‏.‏ يَعْنِي عَلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6265}\hadithtrans{Narrated Ibn Mas`ud:Allah's Messenger (ﷺ) taught me the Tashah-hud as he taught me a Sura from the Qur'an, while my hand was between his hands. (Tashah-hud was) all the best compliments and the prayers and the good things are for Allah. Peace and Allah's Mercy and Blessings be on you, O Prophet! Peace be on us and on the pious slaves of Allah, I testify that none has the right to be worshipped but Allah, and I also testify that Muhammad is Allah's slave and His Apostle. (We used to recite this in the prayer) during the lifetime of the Prophet (ﷺ) , but when he had died, we used to say, "Peace be on the Prophet}}
\hadithdefcmd{bukhari}{6266}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا بِشْرُ بْنُ شُعَيْبٍ، حَدَّثَنِي أَبِي، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ عَلِيًّا ـ يَعْنِي ابْنَ أَبِي طَالِبٍ ـ خَرَجَ مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم وَحَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ حَدَّثَنَا عَنْبَسَةُ حَدَّثَنَا يُونُسُ عَنِ ابْنِ شِهَابٍ قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ ـ رضى الله عنه ـ خَرَجَ مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَقَالَ النَّاسُ يَا أَبَا حَسَنٍ كَيْفَ أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَصْبَحَ بِحَمْدِ اللَّهِ بَارِئًا فَأَخَذَ بِيَدِهِ الْعَبَّاسُ فَقَالَ أَلاَ تَرَاهُ أَنْتَ وَاللَّهِ بَعْدَ الثَّلاَثِ عَبْدُ الْعَصَا وَاللَّهِ إِنِّي لأُرَى رَسُولَ اللَّهِ صلى الله عليه وسلم سَيُتَوَفَّى فِي وَجَعِهِ، وَإِنِّي لأَعْرِفُ فِي وُجُوهِ بَنِي عَبْدِ الْمُطَّلِبِ الْمَوْتَ، فَاذْهَبْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَسْأَلَهُ فِيمَنْ يَكُونُ الأَمْرُ فَإِنْ كَانَ فِينَا عَلِمْنَا ذَلِكَ، وَإِنْ كَانَ فِي غَيْرِنَا أَمَرْنَاهُ فَأَوْصَى بِنَا‏.‏ قَالَ عَلِيٌّ وَاللَّهِ لَئِنْ سَأَلْنَاهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَمْنَعُنَا لاَ يُعْطِينَاهَا النَّاسُ أَبَدًا، وَإِنِّي لاَ أَسْأَلُهَا رَسُولَ اللَّهِ صلى الله عليه وسلم أَبَدًا‏.‏\hadithno{6266}\hadithtrans{Narrated `Abdullah bin `Abbas:`Ali bin Abu Talib came out of the house of the Prophet (ﷺ) during his fatal ailment. The people asked (`Ali), "O Abu Hasan! How is the health of Allah's Messenger (ﷺ) this morning?" `Ali said, "This morning he is better, with the grace of Allah." Al-`Abbas held `Ali by the hand and said, "Don't you see him (about to die)? By Allah, within three days you will be the slave of the stick (i.e., under the command of another ruler). By Allah, I think that Allah's Messenger (ﷺ) will die from his present ailment, for I know the signs of death on the faces of the offspring of `Abdul Muttalib. So let us go to Allah's Messenger (ﷺ) to ask him who will take over the Caliphate. If the authority is given to us, we will know it, and if it is given to somebody else we will request him to recommend us to him. " `Ali said, "By Allah! If we ask Allah's Messenger (ﷺ) for the rulership and he refuses, then the people will never give it to us. Besides, I will never ask Allah's Messenger (ﷺ) for it." (See Hadith No 728, Vol)}}
\hadithdefcmd{bukhari}{6267}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ مُعَاذٍ، قَالَ أَنَا رَدِيفُ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ وَسَعْدَيْكَ‏.‏ ثُمَّ قَالَ مِثْلَهُ ثَلاَثًا ‏"‏ هَلْ تَدْرِي مَا حَقُّ اللَّهِ عَلَى الْعِبَادِ أَنْ يَعْبُدُوهُ وَلاَ يُشْرِكُوا بِهِ شَيْئًا ‏"‏‏.‏ ثُمَّ سَارَ سَاعَةً فَقَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ وَسَعْدَيْكَ‏.‏ قَالَ ‏"‏ هَلْ تَدْرِي مَا حَقُّ الْعِبَادِ عَلَى اللَّهِ إِذَا فَعَلُوا ذَلِكَ أَنْ لاَ يُعَذِّبَهُمْ ‏"‏‏.‏ حَدَّثَنَا هُدْبَةُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنْ مُعَاذٍ، بِهَذَا‏.‏\hadithno{6267}\hadithtrans{Narrated Mu`adh:While I was a companion rider with the Prophet (ﷺ) he said, "O Mu`adh!" I replied, "Labbaik wa Sa`daik." He repeated this call three times and then said, "Do you know what Allah's Right on His slaves is?" I replied, "No." He said, Allah's Right on His slaves is that they should worship Him (Alone) and should not join partners in worship with Him." He said, "O Mu`adh!" I replied, "Labbaik wa Sa`daik." He said, "Do you know what the right of (Allah's) salves on Allah is, if they do that (worship Him Alone and join none in His worship)? It is that He will not punish them." (another chain through Mu'adh)}}
\hadithdefcmd{bukhari}{6268}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، حَدَّثَنَا وَاللَّهِ أَبُو ذَرٍّ، بِالرَّبَذَةِ كُنْتُ أَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرَّةِ الْمَدِينَةِ عِشَاءً اسْتَقْبَلَنَا أُحُدٌ فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ مَا أُحِبُّ أَنَّ أُحُدًا لِي ذَهَبًا يَأْتِي عَلَىَّ لَيْلَةٌ أَوْ ثَلاَثٌ عِنْدِي مِنْهُ دِينَارٌ، إِلاَّ أُرْصِدُهُ لِدَيْنٍ، إِلاَّ أَنْ أَقُولَ بِهِ فِي عِبَادِ اللَّهِ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ وَأَرَانَا بِيَدِهِ‏.‏ ثُمَّ قَالَ ‏"‏ يَا أَبَا ذَرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ وَسَعْدَيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الأَكْثَرُونَ هُمُ الأَقَلُّونَ إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا ‏"‏‏.‏ ثُمَّ قَالَ لِي ‏"‏ مَكَانَكَ لاَ تَبْرَحْ يَا أَبَا ذَرٍّ حَتَّى أَرْجِعَ ‏"‏‏.‏ فَانْطَلَقَ حَتَّى غَابَ عَنِّي، فَسَمِعْتُ صَوْتًا فَخَشِيتُ أَنْ يَكُونَ عُرِضَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرَدْتُ أَنْ أَذْهَبَ، ثُمَّ ذَكَرْتُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَبْرَحْ ‏"‏‏.‏ فَمَكُثْتُ قُلْتُ يَا رَسُولَ اللَّهِ سَمِعْتُ صَوْتًا خَشِيتُ أَنْ يَكُونَ عُرِضَ لَكَ، ثُمَّ ذَكَرْتُ قَوْلَكَ فَقُمْتُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ذَاكَ جِبْرِيلُ أَتَانِي، فَأَخْبَرَنِي أَنَّهُ مَنْ مَاتَ مِنْ أُمَّتِي لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ وَإِنْ زَنَى وَإِنْ سَرَقَ‏.‏ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏‏.‏ قُلْتُ لِزَيْدٍ إِنَّهُ بَلَغَنِي أَنَّهُ أَبُو الدَّرْدَاءِ‏.‏ فَقَالَ أَشْهَدُ لَحَدَّثَنِيهِ أَبُو ذَرٍّ بِالرَّبَذَةِ‏.‏ قَالَ الأَعْمَشُ وَحَدَّثَنِي أَبُو صَالِحٍ عَنْ أَبِي الدَّرْدَاءِ نَحْوَهُ‏.‏ وَقَالَ أَبُو شِهَابٍ عَنِ الأَعْمَشِ ‏"‏ يَمْكُثُ عِنْدِي فَوْقَ ثَلاَثٍ ‏"‏‏.‏\hadithno{6268}\hadithtrans{Narrated Abu Dhar:While I was walking with the Prophet (ﷺ) at the Hurra of Medina in the evening, the mountain of Uhud appeared before us. The Prophet (ﷺ) said, "O Abu Dhar! I would not like to have gold equal to Uhud (mountain) for me, unless nothing of it, not even a single Dinar remains of it with me, for more than one day or three days, except that single Dinar which I will keep for repaying debts. I will spend all of it (the whole amount) among Allah's slaves like this and like this and like this." The Prophet (ﷺ) pointed out with his hand to illustrate it and then said, "O Abu Dhar!" I replied, "Labbaik wa Sa`daik, O Allah's Messenger (ﷺ)!" He said, "Those who have much wealth (in this world) will be the least rewarded (in the Hereafter) except those who do like this and like this (i.e., spend their money in charity)." Then he ordered me, "Remain at your place and do not leave it, O Abu Dhar, till I come back." He went away till he disappeared from me. Then I heard a voice and feared that something might have happened to Allah's Messenger (ﷺ), and I intended to go (to find out) but I remembered the statement of Allah's Messenger (ﷺ) that I should not leave, my place, so I kept on waiting (and after a while the Prophet (ﷺ) came), and I said to him, "O Allah's Messenger (ﷺ), I heard a voice and I was afraid that something might have happened to you, but then I remembered your statement and stayed (there). The Prophet (ﷺ) said, "That was Gabriel who came to me and informed me that whoever among my followers died without joining others in worship with Allah, would enter Paradise." I said, "O Allah's Messenger (ﷺ)! Even if he had committed illegal sexual intercourse and theft?" He said, "Even if he had committed illegal sexual intercourse and theft}}
\hadithdefcmd{bukhari}{6269}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِيمُ الرَّجُلُ الرَّجُلَ مِنْ مَجْلِسِهِ، ثُمَّ يَجْلِسُ فِيهِ ‏"‏‏.‏\hadithno{6269}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "A man should not make another man get up from his (the latter's) seat (in a gathering) in order to sit there}}
\hadithdefcmd{bukhari}{6270}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُقَامَ الرَّجُلُ مِنْ مَجْلِسِهِ وَيَجْلِسَ فِيهِ آخَرُ، وَلَكِنْ تَفَسَّحُوا وَتَوَسَّعُوا‏.‏ وَكَانَ ابْنُ عُمَرَ يَكْرَهُ أَنْ يَقُومَ الرَّجُلُ مِنْ مَجْلِسِهِ، ثُمَّ يُجْلِسَ مَكَانَهُ‏.‏\hadithno{6270}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade that a man should be made to get up from his seat so that another might sit on it, but one should make room and spread out. Ibn `Umar disliked that a man should get up from his seat and then somebody else sit at his place}}
\hadithdefcmd{bukhari}{6271}{حَدَّثَنَا الْحَسَنُ بْنُ عُمَرَ، حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي يَذْكُرُ، عَنْ أَبِي مِجْلَزٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ لَمَّا تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْنَبَ ابْنَةَ جَحْشٍ دَعَا النَّاسَ طَعِمُوا ثُمَّ جَلَسُوا يَتَحَدَّثُونَ ـ قَالَ ـ فَأَخَذَ كَأَنَّهُ يَتَهَيَّأُ لِلْقِيَامِ فَلَمْ يَقُومُوا، فَلَمَّا رَأَى ذَلِكَ قَامَ، فَلَمَّا قَامَ قَامَ مَنْ قَامَ مَعَهُ مِنَ النَّاسِ، وَبَقِيَ ثَلاَثَةٌ، وَإِنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَ لِيَدْخُلَ فَإِذَا الْقَوْمُ جُلُوسٌ، ثُمَّ إِنَّهُمْ قَامُوا فَانْطَلَقُوا ـ قَالَ ـ فَجِئْتُ فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم أَنَّهُمْ قَدِ انْطَلَقُوا، فَجَاءَ حَتَّى دَخَلَ فَذَهَبْتُ أَدْخُلُ، فَأَرْخَى الْحِجَابَ بَيْنِي وَبَيْنَهُ، وَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏إِنَّ ذَلِكُمْ كَانَ عِنْدَ اللَّهِ عَظِيمًا‏\}‏‏.‏\hadithno{6271}\hadithtrans{Narrated Anas bin Malik:When Allah's Messenger (ﷺ) married Zainab bint Jahsh, he invited the people who took their meals and then remained sitting and talking. The Prophet (ﷺ) pretended to be ready to get up, but the people did not get up. When he noticed that, he got up, and when he had got up, some of those people got up along with him and there remained three (who kept on sitting). Then the Prophet (ﷺ) came back and found those people still sitting. Later on those people got up and went away. So I went to the Prophet (ﷺ) and informed him that they had left. The Prophet (ﷺ) came, and entered (his house). I wanted to enter(along with him) but he dropped a curtain between me and him. Allah then revealed: 'O you who believe! Do not enter the Prophet's Houses until leave is given... (to His statement)... Verily! That shall be an enormity, in Allah's sight}}
\hadithdefcmd{bukhari}{6272}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي غَالِبٍ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، عَنْ أَبِيهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِفِنَاءِ الْكَعْبَةِ مُحْتَبِيًا بِيَدِهِ هَكَذَا‏.‏\hadithno{6272}\hadithtrans{Narrated Ibn `Umar:I saw Allah's Messenger (ﷺ) in the courtyard of the Ka`ba in the Ihtiba.' posture putting his hand round his legs like this}}
\hadithdefcmd{bukhari}{6273}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَكْبَرِ الْكَبَائِرِ ‏"‏‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ ‏"‏‏.‏\hadithno{6273}\hadithtrans{Narrated Abu Bakra:Allah's Messenger (ﷺ) said, "Shall I inform you of the biggest of the great sins?" They said, "Yes, O Allah's Apostle!" He said, "To join partners in worship with Allah, and to be undutiful to one's parents}}
\hadithdefcmd{bukhari}{6274}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، مِثْلَهُ، وَكَانَ مُتَّكِئًا فَجَلَسَ فَقَالَ ‏ "‏ أَلاَ وَقَوْلُ الزُّورِ ‏"‏‏.‏ فَمَا زَالَ يُكَرِّرُهَا حَتَّى قُلْنَا لَيْتَهُ سَكَتَ‏.‏\hadithno{6274}\hadithtrans{Narrated Bishr:as above (No. 290) adding: The Prophet (ﷺ) was reclining (leaning) and then he sat up saying, "And I warn you against giving a false statement." And he kept on saying that warning so much so that we said, "Would that he had stopped}}
\hadithdefcmd{bukhari}{6275}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، أَنَّ عُقْبَةَ بْنَ الْحَارِثِ، حَدَّثَهُ قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الْعَصْرَ، فَأَسْرَعَ، ثُمَّ دَخَلَ الْبَيْتَ‏.‏\hadithno{6275}\hadithtrans{Narrated `Uqba bin Al-Harith:Once the Prophet (ﷺ) offered the `Asr prayer and then he walked quickly and entered his house}}
\hadithdefcmd{bukhari}{6276}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَسْطَ السَّرِيرِ، وَأَنَا مُضْطَجِعَةٌ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ تَكُونُ لِيَ الْحَاجَةُ، فَأَكْرَهُ أَنْ أَقُومَ فَأَسْتَقْبِلَهُ فَأَنْسَلُّ انْسِلاَلاً‏.‏\hadithno{6276}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to offer his prayer (while standing) in the midst of the bed, and I used to lie in front of him between him and the Qibla It I had any necessity for getting up and I used to dislike to get up and face him (while he was in prayer), but I would gradually slip away from the bed}}
\hadithdefcmd{bukhari}{6277}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا خَالِدٌ،‏.‏ وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا خَالِدٌ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَخْبَرَنِي أَبُو الْمَلِيحِ، قَالَ دَخَلْتُ مَعَ أَبِيكَ زَيْدٍ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو فَحَدَّثَنَا أَنَّ النَّبِيَّ صلى الله عليه وسلم ذُكِرَ لَهُ صَوْمِي، فَدَخَلَ عَلَىَّ، فَأَلْقَيْتُ لَهُ وِسَادَةً مِنْ أَدَمٍ حَشْوُهَا لِيفٌ، فَجَلَسَ عَلَى الأَرْضِ، وَصَارَتِ الْوِسَادَةُ بَيْنِي وَبَيْنَهُ، فَقَالَ لِي ‏"‏ أَمَا يَكْفِيكَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةُ أَيَّامٍ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ خَمْسًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ سَبْعًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ تِسْعًا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ إِحْدَى عَشْرَةَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ لاَ صَوْمَ فَوْقَ صَوْمِ دَاوُدَ، شَطْرَ الدَّهْرِ، صِيَامُ يَوْمٍ، وَإِفْطَارُ يَوْمٍ ‏"‏‏.‏\hadithno{6277}\hadithtrans{Narrated `Abdullah bin `Amr:The news of my fasting was mentioned to the Prophet (ﷺ) . So he entered upon me and I put for him a leather cushion stuffed with palm-fibres. The Prophet (ﷺ) sat on the floor and the cushion was between me and him. He said to me, "Isn't it sufficient for you (that you fast) three days a month?" I said, "O Allah's Messenger (ﷺ)! (I can fast more than this)." He said, "You may fast) five days a month." I said, "O Allah's Messenger (ﷺ)! (I can fast more than this)." He said, "(You may fast) seven days." I said, "O Allah's Apostle!" He said, "Nine." I said, "O Allah's Messenger (ﷺ)!" He said, "Eleven." I said, "O Allah's Messenger (ﷺ)!" He said, "No fasting is superior to the fasting of (the Prophet David (ﷺ)) which was one half of a year, and he used, to fast on alternate days. (See Hadith No. 300, Vol)}}
\hadithdefcmd{bukhari}{6278}{حَدَّثَنَا يَحْيَى بْنُ جَعْفَرٍ، حَدَّثَنَا يَزِيدُ، عَنْ شُعْبَةَ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، أَنَّهُ قَدِمَ الشَّأْمَ‏.‏ وَحَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، قَالَ ذَهَبَ عَلْقَمَةُ إِلَى الشَّأْمِ، فَأَتَى الْمَسْجِدَ فَصَلَّى رَكْعَتَيْنِ فَقَالَ اللَّهُمَّ ارْزُقْنِي جَلِيسًا‏.‏ فَقَعَدَ إِلَى أَبِي الدَّرْدَاءِ فَقَالَ مِمَّنْ أَنْتَ قَالَ مِنْ أَهْلِ الْكُوفَةِ‏.‏ قَالَ أَلَيْسَ فِيكُمْ صَاحِبُ السِّرِّ الَّذِي كَانَ لاَ يَعْلَمُهُ غَيْرُهُ ـ يَعْنِي حُذَيْفَةَ ـ أَلَيْسَ فِيكُمْ ـ أَوْ كَانَ فِيكُمُ ـ الَّذِي أَجَارَهُ اللَّهُ عَلَى لِسَانِ رَسُولِهِ صلى الله عليه وسلم مِنَ الشَّيْطَانِ ـ يَعْنِي عَمَّارًا ـ أَوَلَيْسَ فِيكُمْ صَاحِبُ السِّوَاكِ وَالْوِسَادِ ـ يَعْنِي ابْنَ مَسْعُودٍ ـ كَيْفَ كَانَ عَبْدُ اللَّهِ يَقْرَأُ ‏\{‏وَاللَّيْلِ إِذَا يَغْشَى‏\}‏‏.‏ قَالَ ‏\{‏وَالذَّكَرِ وَالأُنْثَى‏\}‏‏.‏ فَقَالَ مَا زَالَ هَؤُلاَءِ حَتَّى كَادُوا يُشَكِّكُونِي، وَقَدْ سَمِعْتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{6278}\hadithtrans{Narrated Ibrahim:'Alaqama went to Sham and came to the mosque and offered a two-rak`at prayer, and invoked Allah: "O Allah! Bless me with a (pious) good companion." So he sat beside Abu Ad-Darda' who asked, "From where are you?" He said, "From the people of Kufa." Abu Darda' said, "Wasn't there among you the person who keeps the secrets (of the Prophet (ﷺ) ) which nobody knew except him (i.e., Hudhaifa (bin Al-Yaman)). And isn't there among you the person whom Allah gave refuge from Satan through the request (tongue) of Allah's Messenger (ﷺ)? (i.e., `Ammar). Isn't there among you the one who used to carry the Siwak and the cushion (or pillows (of the Prophets)? (i.e., Ibn Mas`ud). How did Ibn Mas`ud use to recite 'By the night as it conceals (the light)?" (Sura 92). 'Alqama said, "Wadhdhakari Wal Untha' (And by male and female.") Abu Ad-Darda added. 'These people continued to argue with me regarding it till they were about to cause me to have doubts although I heard it from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{6279}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كُنَّا نَقِيلُ وَنَتَغَدَّى بَعْدَ الْجُمُعَةِ‏.‏\hadithno{6279}\hadithtrans{Narrated Sahl bin Sa`d:We used to have a midday nap and take our meals after the Jumua (prayer)}}
\hadithdefcmd{bukhari}{6280}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ مَا كَانَ لِعَلِيٍّ اسْمٌ أَحَبَّ إِلَيْهِ مِنْ أَبِي تُرَابٍ، وَإِنْ كَانَ لَيَفْرَحُ بِهِ إِذَا دُعِيَ بِهَا، جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتَ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ فَلَمْ يَجِدْ عَلِيًّا فِي الْبَيْتِ فَقَالَ ‏"‏ أَيْنَ ابْنُ عَمِّكِ ‏"‏‏.‏ فَقَالَتْ كَانَ بَيْنِي وَبَيْنَهُ شَىْءٌ، فَغَاضَبَنِي فَخَرَجَ فَلَمْ يَقِلْ عِنْدِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لإِنْسَانٍ ‏"‏ انْظُرْ أَيْنَ هُوَ ‏"‏ فَجَاءَ فَقَالَ يَا رَسُولَ اللَّهِ هُوَ فِي الْمَسْجِدِ رَاقِدٌ‏.‏ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ مُضْطَجِعٌ، قَدْ سَقَطَ رِدَاؤُهُ عَنْ شِقِّهِ، فَأَصَابَهُ تُرَابٌ، فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُهُ عَنْهُ ـ وَهْوَ يَقُولُ ‏"‏ قُمْ أَبَا تُرَابٍ، قُمْ أَبَا تُرَابٍ ‏"‏‏.‏\hadithno{6280}\hadithtrans{Narrated Sahl bin Sa`d:There was no name dearer to `Ali than his nickname Abu Turab (the father of dust). He used to feel happy whenever he was called by this name. Once Allah's Messenger (ﷺ) came to the house of Fatima but did not find `Ali in the house. So he asked "Where is your cousin?" She replied, "There was something (a quarrel) between me and him whereupon he got angry with me and went out without having a midday nap in my house." Allah's Messenger (ﷺ) asked a person to look for him. That person came, and said, "O Allah's Messenger (ﷺ)! He (Ali) is sleeping in the mosque." So Allah's Messenger (ﷺ) went there and found him lying. His upper body cover had fallen off to one side of his body, and so he was covered with dust. Allah's Messenger (ﷺ) started cleaning the dust from him, saying, "Get up, O Abu Turab! Get up, Abu Turab!" (See Hadith No. 432, Vol)}}
\hadithdefcmd{bukhari}{6281}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ ثُمَامَةَ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، كَانَتْ تَبْسُطُ لِلنَّبِيِّ صلى الله عليه وسلم نِطَعًا فَيَقِيلُ عِنْدَهَا عَلَى ذَلِكَ النِّطَعِ ـ قَالَ ـ فَإِذَا نَامَ النَّبِيُّ صلى الله عليه وسلم أَخَذَتْ مِنْ عَرَقِهِ وَشَعَرِهِ، فَجَمَعَتْهُ فِي قَارُورَةٍ، ثُمَّ جَمَعَتْهُ فِي سُكٍّ ـ قَالَ ـ فَلَمَّا حَضَرَ أَنَسَ بْنَ مَالِكٍ الْوَفَاةُ أَوْصَى أَنْ يُجْعَلَ فِي حَنُوطِهِ مِنْ ذَلِكَ السُّكِّ ـ قَالَ ـ فَجُعِلَ فِي حَنُوطِهِ‏.‏\hadithno{6281}\hadithtrans{Narrated Thumama:Anas said, "Um Sulaim used to spread a leather sheet for the Prophet (ﷺ) and he used to take a midday nap on that leather sheet at her home." Anas added, "When the Prophet (ﷺ) had slept, she would take some of his sweat and hair and collect it (the sweat) in a bottle and then mix it with Suk (a kind of perfume) while he was still sleeping. "When the death of Anas bin Malik approached, he advised that some of that Suk be mixed with his Hanut (perfume for embalming the dead body), and it was mixed with his Hanut}}
\hadithdefcmd{bukhari}{6283}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَهَبَ إِلَى قُبَاءٍ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ، وَكَانَتْ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ، فَدَخَلَ يَوْمًا فَأَطْعَمَتْهُ، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ يَضْحَكُ‏.‏ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ ‏"‏‏.‏ ـ أَوْ قَالَ ‏"‏ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ شَكَّ إِسْحَاقُ ـ قُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَدَعَا ثُمَّ وَضَعَ رَأْسَهُ فَنَامَ، ثُمَّ اسْتَيْقَظَ يَضْحَكُ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ، غُزَاةً فِي سَبِيلِ اللَّهِ، يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ، مُلُوكًا عَلَى الأَسِرَّةِ ‏"‏‏.‏ أَوْ ‏"‏ مِثْلَ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏‏.‏ فَقُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏‏.‏ فَرَكِبَتِ الْبَحْرَ زَمَانَ مُعَاوِيَةَ، فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ، فَهَلَكَتْ‏.‏\hadithno{6283}\hadithtrans{Narrated Anas bin Malik:Whenever Allah's Messenger (ﷺ) went to Quba, he used to visit Um Haram bint Milhan who would offer him meals; and she was the wife of 'Ubada bin As-samit. One day he went to her house and she offered him a meal, and after that he slept, and then woke up smiling. She (Um Haram) said, "I asked him, 'What makes you laugh, O Allah's Messenger (ﷺ)?' He said, 'Some people of my followers were displayed before me as warriors fighting for Allah's Cause and sailing over this sea, kings on thrones,' or said, 'like kings on thrones.' (The narrator, 'Is-haq is in doubt about it.) I (Um Haram) said, 'O Allah's Apostle! Invoke Allah that He may make me one of them.' He invoked (Allah) for her and then lay his head and slept again and then woke up smiling. I asked, 'What makes you laugh, O Allah's Messenger (ﷺ)?' He said, 'Some people of my followers were displayed before me as warriors fighting for Allah's Cause and sailing over this sea, kings on the thrones,' or said, 'like kings on the thrones.' I (Um Haram) said, 'O Allah's Messenger (ﷺ)! Invoke Allah that He may make me one of them.' He said, You will be amongst the first ones." It is said that Um Haram sailed over the sea at the time of Muawiya, and on coming out of the sea, she fell down from her riding animal and died}}
\hadithdefcmd{bukhari}{6284}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ، وَعَنْ بَيْعَتَيْنِ اشْتِمَالِ الصَّمَّاءِ، وَالاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ، لَيْسَ عَلَى فَرْجِ الإِنْسَانِ مِنْهُ شَىْءٌ، وَالْمُلاَمَسَةِ، وَالْمُنَابَذَةِ‏.‏ تَابَعَهُ مَعْمَرٌ وَمُحَمَّدُ بْنُ أَبِي حَفْصَةَ وَعَبْدُ اللَّهِ بْنُ بُدَيْلٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{6284}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) forbade two kinds of dresses and two kinds of bargains; Ishtimal As-Samma and Al- Ihtiba in one garment with no part of it covering one's private parts. (The two kinds of bargains were:) Al-Mulamasa and Al-Munabadha}}
\hadithdefcmd{bukhari}{6286}{حَدَّثَنَا مُوسَى، عَنْ أَبِي عَوَانَةَ، حَدَّثَنَا فِرَاسٌ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، حَدَّثَتْنِي عَائِشَةُ أُمُّ الْمُؤْمِنِينَ، قَالَتْ إِنَّا كُنَّا أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم عِنْدَهُ جَمِيعًا، لَمْ تُغَادَرْ مِنَّا وَاحِدَةٌ، فَأَقْبَلَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ تَمْشِي، لاَ وَاللَّهِ مَا تَخْفَى مِشْيَتُهَا مِنْ مِشْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَآهَا رَحَّبَ قَالَ ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏‏.‏ ثُمَّ أَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ، ثُمَّ سَارَّهَا فَبَكَتْ بُكَاءً شَدِيدًا، فَلَمَّا رَأَى حُزْنَهَا سَارَّهَا الثَّانِيَةَ إِذَا هِيَ تَضْحَكُ‏.‏ فَقُلْتُ لَهَا أَنَا مِنْ بَيْنِ نِسَائِهِ خَصَّكِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالسِّرِّ مِنْ بَيْنِنَا، ثُمَّ أَنْتِ تَبْكِينَ، فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلْتُهَا عَمَّا سَارَّكِ قَالَتْ مَا كُنْتُ لأُفْشِيَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سِرَّهُ‏.‏ فَلَمَّا تُوُفِّيَ قُلْتُ لَهَا عَزَمْتُ عَلَيْكِ بِمَا لِي عَلَيْكِ مِنَ الْحَقِّ لَمَّا أَخْبَرْتِنِي‏.‏ قَالَتْ أَمَّا الآنَ فَنَعَمْ‏.‏ فَأَخْبَرَتْنِي قَالَتْ أَمَّا حِينَ سَارَّنِي فِي الأَمْرِ الأَوَّلِ، فَإِنَّهُ أَخْبَرَنِي أَنَّ جِبْرِيلَ كَانَ يُعَارِضُهُ بِالْقُرْآنِ كُلَّ سَنَةٍ مَرَّةً ‏"‏ وَإِنَّهُ قَدْ عَارَضَنِي بِهِ الْعَامَ مَرَّتَيْنِ، وَلاَ أَرَى الأَجَلَ إِلاَّ قَدِ اقْتَرَبَ، فَاتَّقِي اللَّهَ وَاصْبِرِي، فَإِنِّي نِعْمَ السَّلَفُ أَنَا لَكَ ‏"‏‏.‏ قَالَتْ فَبَكَيْتُ بُكَائِي الَّذِي رَأَيْتِ، فَلَمَّا رَأَى جَزَعِي سَارَّنِي الثَّانِيَةَ قَالَ ‏"‏ يَا فَاطِمَةُ أَلاَ تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ الْمُؤْمِنِينَ ـ أَوْ ـ سَيِّدَةَ نِسَاءِ هَذِهِ الأُمَّةِ ‏"‏‏.‏\hadithno{6286}\hadithtrans{Narrated `Aisha:Mother of the Believers: We, the wives of the Prophet (ﷺ) were all sitting with the Prophet (ﷺ) and none of us had left when Fatima came walking, and by Allah, her gait was very similar to that of Allah's Messenger (ﷺ) .' When he saw her, he welcomed her, saying, "Welcome, O my daughter!" Then he made her sit on his right or his left, confided something to her, whereupon she wept bitterly. When he noticed her sorrow, he confided something else to her for the second time, and she started laughing. Only I from among the Prophet's wives said to her, "(O Fatima), Allah's Messenger (ﷺ) selected you from among us for the secret talk and still you weep?" When Allah's Messenger (ﷺ) got up (and went away), I asked her, "What did he confide to you?" She said, "I wouldn't disclose the secrets of Allah's Messenger (ﷺ)" But when he died I asked her, "I beseech you earnestly by what right I have on you, to tell me (that secret talk which the Prophet had with you)" She said, "As you ask me now, yes, (I will tell you)." She informed me, saying, "When he talked to me secretly the first time, he said that Gabriel used to review the Qur'an with him once every year. He added, 'But this year he reviewed it with me twice, and therefore I think that my time of death has approached. So, be afraid of Allah, and be patient, for I am the best predecessor for you (in the Hereafter).' " Fatima added, "So I wept as you (`Aisha) witnessed. And when the Prophet (ﷺ) saw me in this sorrowful state, he confided the second secret to me saying, 'O Fatima! Will you not be pleased that you will be chief of all the believing women (or chief of the women of this nation i.e. my followers?)}}
\hadithdefcmd{bukhari}{6287}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عَبَّادُ بْنُ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ مُسْتَلْقِيًا، وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى‏.‏\hadithno{6287}\hadithtrans{Narrated the uncle of `Abbas bin Tamim:I saw Allah's Messenger (ﷺ) lying on his back in the mosque and putting one of his legs over the other}}
\hadithdefcmd{bukhari}{6288}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ،‏.‏ وَحَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانُوا ثَلاَثَةٌ فَلاَ يَتَنَاجَى اثْنَانِ دُونَ الثَّالِثِ ‏"‏‏.‏\hadithno{6288}\hadithtrans{Narrated `Abdullah:the Prophet (ﷺ) said "When three persons are together, then no two of them should hold secret counsel excluding the third person}}
\hadithdefcmd{bukhari}{6289}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ صَبَّاحٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، أَسَرَّ إِلَىَّ النَّبِيُّ صلى الله عليه وسلم سِرًّا فَمَا أَخْبَرْتُ بِهِ أَحَدًا بَعْدَهُ، وَلَقَدْ سَأَلَتْنِي أُمُّ سُلَيْمٍ فَمَا أَخْبَرْتُهَا بِهِ‏.‏\hadithno{6289}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) confided to me a secret which I did not disclose to anybody after him. And Um Sulaim asked me (about that secret) but I did not tell her}}
\hadithdefcmd{bukhari}{6290}{حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏إِذَا كُنْتُمْ ثَلاَثَةً فَلاَ يَتَنَاجَى رَجُلاَنِ دُونَ الآخَرِ، حَتَّى تَخْتَلِطُوا بِالنَّاسِ، أَجْلَ أَنْ يُحْزِنَهُ‏\}‏‏.‏\hadithno{6290}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "When you are three persons sitting together, then no two of you should hold secret counsel excluding the third person until you are with some other people too, for that would grieve him}}
\hadithdefcmd{bukhari}{6291}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَسَمَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا قِسْمَةً فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ إِنَّ هَذِهِ لَقِسْمَةٌ مَا أُرِيدَ بِهَا وَجْهُ اللَّهِ‏.‏ قُلْتُ أَمَا وَاللَّهِ لآتِيَنَّ النَّبِيَّ صلى الله عليه وسلم فَأَتَيْتُهُ وَهْوَ فِي مَلأٍ، فَسَارَرْتُهُ فَغَضِبَ حَتَّى احْمَرَّ وَجْهُهُ، ثُمَّ قَالَ ‏ "‏ رَحْمَةُ اللَّهِ عَلَى مُوسَى، أُوذِيَ بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏‏.‏\hadithno{6291}\hadithtrans{Narrated `Abdullah:One day the Prophet (ﷺ) divided and distributed something amongst the people whereupon an Ansari man said, "In this division Allah's Countenance has not been sought." I said, "By Allah! I will go (and inform) the Prophet." So I went to him while he was with a group of people, and I secretly informed him of that, whereupon he became so angry that his face became red, and he then said, "May Allah bestow His Mercy on Moses (for) he was hurt more than that, yet he remained patient}}
\hadithdefcmd{bukhari}{6292}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَس ٍ ـ رضى الله عنه ـ قَالَ أُقِيمَتِ الصَّلاَةُ وَرَجُلٌ يُنَاجِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَمَا زَالَ يُنَاجِيهِ حَتَّى نَامَ أَصْحَابُهُ، ثُمَّ قَامَ فَصَلَّى‏.‏\hadithno{6292}\hadithtrans{Narrated Anas:The Iqama for the prayer was announced while a man was talking to Allah's Messenger (ﷺ) privately. He continued talking in that way till the Prophet's companions slept, and afterwards the Prophet (ﷺ) got up and offered the prayer with them}}
\hadithdefcmd{bukhari}{6293}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏\{‏لاَ تَتْرُكُوا النَّارَ فِي بُيُوتِكُمْ حِينَ تَنَامُونَ‏\}‏‏.‏\hadithno{6293}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) said, "Do not keep the fire burning in your houses when you go to bed}}
\hadithdefcmd{bukhari}{6294}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ احْتَرَقَ بَيْتٌ بِالْمَدِينَةِ عَلَى أَهْلِهِ مِنَ اللَّيْلِ، فَحُدِّثَ بِشَأْنِهِمُ النَّبِيُّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ هَذِهِ النَّارَ إِنَّمَا هِيَ عَدُوٌّ لَكُمْ، فَإِذَا نِمْتُمْ فَأَطْفِئُوهَا عَنْكُمْ ‏"‏‏.‏\hadithno{6294}\hadithtrans{Narrated Abu Musa:One night a house in Medina was burnt with its occupants. The Prophet (ﷺ) spoke about them, saying, "This fire is indeed your enemy, so whenever you go to bed, put it out to protect yourselves}}
\hadithdefcmd{bukhari}{6295}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ كَثِيرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمِّرُوا الآنِيَةَ وَأَجِيفُوا الأَبْوَابَ، وَأَطْفِئُوا الْمَصَابِيحَ، فَإِنَّ الْفُوَيْسِقَةَ رُبَّمَا جَرَّتِ الْفَتِيلَةَ فَأَحْرَقَتْ أَهْلَ الْبَيْتِ ‏"‏‏.‏\hadithno{6295}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "(At bedtime) cover the utensils, close the doors, and put out the lights, lest the evil creature (the rat) should pull away the wick and thus burn the people of the house}}
\hadithdefcmd{bukhari}{6296}{حَدَّثَنَا حَسَّانُ بْنُ أَبِي عَبَّادٍ، حَدَّثَنَا هَمَّامٌ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَطْفِئُوا الْمَصَابِيحَ بِاللَّيْلِ إِذَا رَقَدْتُمْ، وَغَلِّقُوا الأَبْوَابَ، وَأَوْكُوا الأَسْقِيَةَ، وَخَمِّرُوا الطَّعَامَ وَالشَّرَابَ ‏"‏‏.‏ ـ قَالَ هَمَّامٌ وَأَحْسِبُهُ قَالَ ـ ‏"‏وَلَوْ بِعُودٍ يَعْرُضُهُ\hadithno{6296}\hadithtrans{Narrated Jabir:Allah's Apostle said, "When you intend going to bed at night, put out the lights, close the doors, tie the mouths of the water skins, and cover your food and drinks." Hamrnam said, "I think he (the other narrator) added, 'even with piece of wood across the utensil}}
\hadithdefcmd{bukhari}{6297}{حَدَّثَنَا يَحْيَى بْنُ قُزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْفِطْرَةُ خَمْسٌ الْخِتَانُ، وَالاِسْتِحْدَادُ، وَنَتْفُ الإِبْطِ، وَقَصُّ الشَّارِبِ، وَتَقْلِيمُ الأَظْفَارِ ‏"‏‏.‏\hadithno{6297}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said "Five things are in accordance with Al Fitra (i.e. the tradition of prophets): to be circumcised, to shave the pelvic region, to pull out the hair of the armpits, to cut short the moustaches, and to clip the nails}}
\hadithdefcmd{bukhari}{6298}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اخْتَتَنَ إِبْرَاهِيمُ بَعْدَ ثَمَانِينَ سَنَةً، وَاخْتَتَنَ بِالْقَدُومِ ‏"‏‏.‏ مُخَفَّفَةً‏.‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا الْمُغِيرَةُ عَنْ أَبِي الزِّنَادِ وَقَالَ ‏"‏بِالْقَدُّومِ"‏‏ وَهُوَ مَوْضِعٌ مُشَدَّدٌ\hadithno{6298}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said "The Prophet) Abraham circumcised himself after he had passed the age of eighty years and he circumcised himself with an adze}}
\hadithdefcmd{bukhari}{6299}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا عَبَّادُ بْنُ مُوسَى، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سُئِلَ ابْنُ عَبَّاسٍ مِثْلُ مَنْ أَنْتَ حِينَ قُبِضَ النَّبِيُّ صلى الله عليه وسلم قَالَ أَنَا يَوْمَئِذٍ مَخْتُونٌ‏.‏ قَالَ وَكَانُوا لاَ يَخْتِنُونَ الرَّجُلَ حَتَّى يُدْرِكَ‏.‏\hadithno{6299}\hadithtrans{Narrated Said bin Jubair:Ibn 'Abbas was asked, "How old were you when the Prophet (ﷺ) died?" He replied. "At that time I had been circumcised." At that time, people did not circumcise the boys till they attained the age of puberty. Sa'id bin Jubair said, "Ibn 'Abbas said, 'When the Prophet died, I had already been circumcised}}
\hadithdefcmd{bukhari}{6300}{وَقَالَ ابْنُ إِدْرِيسَ عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قُبِضَ النَّبِيُّ صلى الله عليه وسلم وَأَنَا خَتِينٌ‏.‏\hadithno{6300}\hadithtrans{Sa'id ibn Jubair said, "Ibn 'Abbas said, 'When the Prophet (ﷺ) died, I had already been circumcised}}
\hadithdefcmd{bukhari}{6301}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ مِنْكُمْ فَقَالَ فِي حَلِفِهِ بِاللاَّتِ وَالْعُزَّى‏.‏ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ‏.‏ فَلْيَتَصَدَّقْ ‏"‏‏.‏\hadithno{6301}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever among you takes an oath wherein he says, 'By Al-Lat and Al-`Uzza,' names of two Idols worshipped by the Pagans, he should say, 'None has the right to be worshipped but Allah; And whoever says to his friend, 'Come, let me gamble with you ! He should give something in charity. " (See Hadith No)}}
\hadithdefcmd{bukhari}{6302}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِسْحَاقُ ـ هُوَ ابْنُ سَعِيدٍ ـ عَنْ سَعِيدٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُنِي مَعَ النَّبِيِّ صلى الله عليه وسلم بَنَيْتُ بِيَدِي بَيْتًا، يُكِنُّنِي مِنَ الْمَطَرِ، وَيُظِلُّنِي مِنَ الشَّمْسِ، مَا أَعَانَنِي عَلَيْهِ أَحَدٌ مِنْ خَلْقِ اللَّهِ‏.‏\hadithno{6302}\hadithtrans{Narrated Ibn `Umar:During the life-time of the Prophet (ﷺ) I built a house with my own hands so that it might protect me from the rain and shade me from the sun; and none of Allah's creatures assisted me in building it}}
\hadithdefcmd{bukhari}{6303}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو قَالَ ابْنُ عُمَرَ وَاللَّهِ مَا وَضَعْتُ لَبِنَةً عَلَى لَبِنَةٍ، وَلاَ غَرَسْتُ نَخْلَةً، مُنْذُ قُبِضَ النَّبِيُّ صلى الله عليه وسلم‏.‏ قَالَ سُفْيَانُ فَذَكَرْتُهُ لِبَعْضِ أَهْلِهِ قَالَ وَاللَّهِ لَقَدْ بَنَى بَيْتًا‏.‏ قَالَ سُفْيَانُ قُلْتُ فَلَعَلَّهُ قَالَ قَبْلَ أَنْ يَبْنِيَ‏.‏\hadithno{6303}\hadithtrans{Narrated `Amr:Ibn `Umar said, "By Allah, I have not put a brick over a brick (i.e. constructed a building) or planted any date-palm tree since the death of the Prophet." Sufyan (the sub narrator) said, "I told this narration (of Ibn `Umar) to one of his (Ibn `Umar's) relatives, and he said, 'By Allah, he did build (something.' "Sufyan added, "I said, 'He must have said (the above narration) before he built}}
